-- List the ID of the products sold on 2007/6/1
-- . using join
-- . using a subquery
-- . using a subquery with IN

select d.product_id from orders o, order_details d
	where o.id = d.order_id
	and o.date_ordered = '2007-6-1';

select d.product_id
	from order_details d,
		(select * from orders where date_ordered='2007-6-1') as o
	where o.id = d.order_id;

select product_id from order_details
	where order_id in
		(select id from orders where date_ordered = '2007-6-1');
	
-- List the descriptions of the products sold on 2007/6/1
-- NOTE: it looks somewhat complex, but note that it simply reuse the
--       previous query as a subquery.

select description from products
	where id in
		(select product_id from order_details
			where order_id in
				(select id from orders
					where date_ordered = '2007-6-1'));

-- Find the CPU products that are cheaper  than Intel Pentium D
-- . using join
-- . using subquery

select * from products p1, products p2 where
	p1.id <> p2.id and p1.category = 'CPU'
	and p2.description = 'Intel Pentium D' and p1.price < p2.price;

select * from products
	where category = 'CPU' and
		price < (select price from products
				where description = 'Intel Pentium D');

-- Zip codes from the vendors table and the customers table
-- . union
-- . intersect (without using the intersect operator)
-- . difference (without using the difference operator)

select zip from vendors
union
select zip from customers;

select zip from vendors where zip in (select zip from customers);

select zip from vendors where zip not in (select zip from customers);

-- Find the products that are cheaper than the average price of their category
-- NOTE: this is a correlated subquery.

select * from products p
	where p.price < (select avg(price) from products p2
				where p2.category = p.category);

-- Find the CPU products that are more expensive than all/any HD products

select * from products
	where category = 'CPU'
	and price > all (select price from products where category = 'HD');

select * from products
	where category = 'CPU'
	and price > any (select price from products where category = 'HD');

-- Find the customers who live with another customer
-- NOTE: another correlated subquery, using EXISTS

select * from customers c1
	where exists (select * from customers c2
			where c2.address = c1.address
			and c2.id <> c1.id );

